@@ -1,15 +1,12 @@
 import pytest
 
-from freenit.config import getConfig
 from freenit.models.user import User
 
 from . import factories
 
-config = getConfig()
-
 
+@pytest.mark.asyncio
 class TestUser:
-    @pytest.mark.asyncio
     async def test_get_profile(self, client):
         user: User = factories.User()
         await user.save()
@@ -17,7 +14,6 @@ class TestUser:
         response = client.get("/profile")
         assert response.status_code == 200
 
-    @pytest.mark.asyncio
     async def test_patch_profile(self, client):
         admin: User = factories.User()
         await admin.save()
@@ -30,7 +26,6 @@ class TestUser:
         assert response.status_code == 200
         assert response.json()["email"] == data["email"]
 
-    @pytest.mark.asyncio
     async def test_get_user_list(self, client):
         admin: User = factories.User()
         await admin.save()
@@ -38,7 +33,6 @@ class TestUser:
         response = client.get(f"/users")
         assert response.status_code == 200
 
-    @pytest.mark.asyncio
     async def test_get_user_by_id(self, client):
         admin: User = factories.User()
         await admin.save()
@@ -46,7 +40,6 @@ class TestUser:
         response = client.get(f"/users/{admin.id}")
         assert response.status_code == 200
 
-    @pytest.mark.asyncio
     async def test_delete_user(self, client):
         admin: User = factories.User()
         await admin.save()
